@@ -5,6 +5,7 @@
 
 from theanolm.backend.exceptions import *
 from theanolm.backend.filetypes import TextFileType
+from theanolm.backend.gpu import get_default_device, log_free_mem
 from theanolm.backend.parameters import Parameters
 from theanolm.backend.classdistribution import UniformDistribution
 from theanolm.backend.classdistribution import LogUniformDistribution
@@ -14,3 +15,4 @@ from theanolm.backend.probfunctions import interpolate_linear
 from theanolm.backend.probfunctions import interpolate_loglinear
 from theanolm.backend.probfunctions import logprob_type
 from theanolm.backend.operations import conv1d, conv2d
+from theanolm.backend.operations import l1_norm, sum_of_squares
